# psi_eligibility
PSIs REST based service to modify candidate test eligibilities.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import psi_eligibility 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import psi_eligibility
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import psi_eligibility
from psi_eligibility.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: oauth
configuration = psi_eligibility.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = psi_eligibility.DefaultApi(psi_eligibility.ApiClient(configuration))
account_code = 'account_code_example' # str | provided client specific account code.
candidate_id = 'candidate_id_example' # str | The unique candidate id to act on.
test_code = 'test_code_example' # str | The test code.

try:
    # Cancel a candidate's eligibility record.
    api_instance.cancel_candidate_eligibility(account_code, candidate_id, test_code)
except ApiException as e:
    print("Exception when calling DefaultApi->cancel_candidate_eligibility: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://apiuatapi.psiexams.com/eligibility_service/1.0.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**cancel_candidate_eligibility**](docs/DefaultApi.md#cancel_candidate_eligibility) | **DELETE** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Cancel a candidate&#39;s eligibility record.
*DefaultApi* | [**create_candidate**](docs/DefaultApi.md#create_candidate) | **POST** /accounts/{account_code}/candidates | Create a new candidate eligibility record.
*DefaultApi* | [**get_candidate**](docs/DefaultApi.md#get_candidate) | **GET** /accounts/{account_code}/candidates/{candidate_id} | Get the eligiblities associated with the candidate id.
*DefaultApi* | [**get_candidate_eligibilities**](docs/DefaultApi.md#get_candidate_eligibilities) | **GET** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Get the eligiblities associated with the candidate id.
*DefaultApi* | [**get_test_launch_info**](docs/DefaultApi.md#get_test_launch_info) | **GET** /eligibilities/{psi_eligibility_code}/testLaunchInfo | GET test launch url
*DefaultApi* | [**modify_vouchers_of_eligibility**](docs/DefaultApi.md#modify_vouchers_of_eligibility) | **PUT** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code}/vouchers | Associate a set of voucher codes to PSI Candidate Test Eligibility record. Previously attached vouchers to the eligibility record but not listed in the input would be unlinked from the eligibility record. Voucher Codes are agreed upon codes between PSI and the customer (identified by account_code)
*DefaultApi* | [**update_candidate_eligibility**](docs/DefaultApi.md#update_candidate_eligibility) | **PUT** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Update an existing candidate&#39;s eligibility record.


## Documentation For Models

 - [AdditionalAttributeModel](docs/AdditionalAttributeModel.md)
 - [CandidateModel](docs/CandidateModel.md)
 - [EligibilityModel](docs/EligibilityModel.md)
 - [EligibilityResponseModel](docs/EligibilityResponseModel.md)
 - [ErrorModel](docs/ErrorModel.md)
 - [ExistingEligibilityModel](docs/ExistingEligibilityModel.md)
 - [TestLaunchInfoModel](docs/TestLaunchInfoModel.md)


## Documentation For Authorization


## default

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://apiuatapi.psiexams.com/authorize
- **Scopes**: N/A

## oauth

- **Type**: OAuth
- **Flow**: password
- **Authorization URL**: 
- **Scopes**: N/A


## Author



